;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "grip-mode" "20250731.213"
  "Instant GitHub-flavored Markdown/Org preview using grip."
  '((emacs "24.4"))
  :url "https://github.com/seagle0128/grip-mode"
  :commit "c965a344ab950c6b4ef788c7b9e8792a95a139d1"
  :revdesc "c965a344ab95"
  :keywords '("convenience" "markdown" "preview")
  :authors '(("Vincent Zhang" . "seagle0128@gmail.com"))
  :maintainers '(("Vincent Zhang" . "seagle0128@gmail.com")))
